@@ -25,6 +25,8 @@ const NUM_LOG_EVENTS = 10; // number of log events to fetch when requesting more
 
 const INDICATOR_OFFSET = 5; // TODO: should be based on line spacing
 
+const MARGIN = 6;
+
 // Workaround for GtkTextView growing horizontally over time when
 // added to a GtkScrolledWindow with horizontal scrolling disabled
 const TextView = new Lang.Class({
@@ -47,6 +49,8 @@ const TextView = new Lang.Class({
         context.add_class('dim-label');
         this._dimColor = context.get_color(Gtk.StateFlags.NORMAL);
         context.restore();
+
+        this.parent();
     },
 
     vfunc_draw: function(cr) {
@@ -60,9 +64,11 @@ const TextView = new Lang.Class({
         let location = this.get_iter_location(iter);
         let [, y] = this.buffer_to_window_coords(Gtk.TextWindowType.TEXT,
                                                  location.x, location.y);
+        let border = this.border_width;
 
         Gdk.cairo_set_source_rgba(cr, this._dimColor);
-        cr.rectangle(0, y + INDICATOR_OFFSET, this.get_allocated_width(), 1);
+        cr.rectangle(border, y + INDICATOR_OFFSET,
+                     this.get_allocated_width() - 2 * border, 1);
         cr.fill();
         cr.$dispose();
     },
@@ -146,7 +152,7 @@ const ChatView = new Lang.Class({
         let tagTable = buffer.get_tag_table();
         let tags = [
           { name: 'nick',
-            left_margin: 0 },
+            left_margin: MARGIN },
           { name: 'gap',
             pixels_above_lines: 10 },
           { name: 'message',
@@ -154,16 +160,16 @@ const ChatView = new Lang.Class({
           { name: 'highlight',
             weight: Pango.Weight.BOLD },
           { name: 'status',
-            left_margin: 0,
+            left_margin: MARGIN,
             indent: 0,
             justification: Gtk.Justification.RIGHT },
           { name: 'timestamp',
-            left_margin: 0,
+            left_margin: MARGIN,
             indent: 0,
             weight: Pango.Weight.BOLD,
             justification: Gtk.Justification.RIGHT },
           { name: 'action',
-            left_margin: 0 },
+            left_margin: MARGIN },
           { name: 'url',
             underline: Pango.Underline.SINGLE
           }
@@ -222,11 +228,8 @@ const ChatView = new Lang.Class({
 
         this._view = new TextView({ editable: false, cursor_visible: false,
                                     visible: true,
-                                    wrap_mode: Gtk.WrapMode.WORD_CHAR });
-        this._view.set_border_window_size(Gtk.TextWindowType.TOP, 6);
-        this._view.set_border_window_size(Gtk.TextWindowType.BOTTOM, 6);
-        this._view.set_border_window_size(Gtk.TextWindowType.LEFT, 6);
-        this._view.set_border_window_size(Gtk.TextWindowType.RIGHT, 6);
+                                    wrap_mode: Gtk.WrapMode.WORD_CHAR,
+                                    right_margin: MARGIN });
 
         this.widget.add(this._view);
         this.widget.show_all();
@@ -319,7 +322,7 @@ const ChatView = new Lang.Class({
         tabs.set_tab(0, Pango.TabAlign.LEFT, this._maxNickChars * pixelWidth);
         this._view.tabs = tabs;
         this._view.indent = -this._maxNickChars * pixelWidth;
-        this._view.left_margin = this._maxNickChars * pixelWidth;
+        this._view.left_margin = MARGIN + this._maxNickChars * pixelWidth;
     },
 
     _updateActive: function() {
@@ -599,7 +602,7 @@ const ChatView = new Lang.Class({
         let daysAgo = todayMidnight.difference(dateMidnight) / GLib.TIME_SPAN_DAY;
 
         let format;
-        let desktopSettings = new Gio.Settings({ schema: 'org.gnome.desktop.interface' });
+        let desktopSettings = new Gio.Settings({ schema_id: 'org.gnome.desktop.interface' });
         let clockFormat = desktopSettings.get_string('clock-format');
         let hasAmPm = date.format('%p') != '';
 
